@@ -28,9 +28,12 @@
 
 #include "ion_wettercom.h"
 
+#include <KIO/Job>
 #include <KUnitConversion/Converter>
 #include <KLocalizedString>
 
+#include <QCryptographicHash>
+#include <QXmlStreamReader>
 #include <QLocale>
 #include <QDebug>
 
@@ -42,12 +45,10 @@ WetterComIon::WetterComIon(QObject *parent, const QVariantList &args)
         : IonInterface(parent, args)
 
 {
-    Q_UNUSED(args)
-
 #if defined(MIN_POLL_INTERVAL)
     setMinimumPollingInterval(MIN_POLL_INTERVAL);
 #endif
-    init();
+    setInitialized(true);
 }
 
 WetterComIon::~WetterComIon()
@@ -74,173 +75,168 @@ void WetterComIon::reset()
     updateAllSources();
 }
 
-void WetterComIon::init()
-{
-    setInitialized(true);
-}
-
-QMap<QString, IonInterface::ConditionIcons> WetterComIon::setupCommonIconMappings(void) const
+QMap<QString, IonInterface::ConditionIcons> WetterComIon::setupCommonIconMappings() const
 {
     QMap<QString, ConditionIcons> conditionList;
 
-    conditionList["3"]  = Overcast;
-    conditionList["30"] = Overcast;
-    conditionList["4"]  = Haze;
-    conditionList["40"] = Haze;
-    conditionList["45"] = Haze;
-    conditionList["48"] = Haze;
-    conditionList["49"] = Haze;
-    conditionList["5"]  = Mist;
-    conditionList["50"] = Mist;
-    conditionList["51"] = Mist;
-    conditionList["53"] = Mist;
-    conditionList["55"] = Mist;
-    conditionList["56"] = FreezingDrizzle;
-    conditionList["57"] = FreezingDrizzle;
-    conditionList["6"]  = Rain;
-    conditionList["60"] = LightRain;
-    conditionList["61"] = LightRain;
-    conditionList["63"] = Rain;
-    conditionList["65"] = Rain;
-    conditionList["66"] = FreezingRain;
-    conditionList["67"] = FreezingRain;
-    conditionList["68"] = RainSnow;
-    conditionList["69"] = RainSnow;
-    conditionList["7"]  = Snow;
-    conditionList["70"] = LightSnow;
-    conditionList["71"] = LightSnow;
-    conditionList["73"] = Snow;
-    conditionList["75"] = Flurries;
-    conditionList["8"]  = Showers;
-    conditionList["81"] = Showers;
-    conditionList["82"] = Showers;
-    conditionList["83"] = RainSnow;
-    conditionList["84"] = RainSnow;
-    conditionList["85"] = Snow;
-    conditionList["86"] = Snow;
-    conditionList["9"] = Thunderstorm;
-    conditionList["90"] = Thunderstorm;
-    conditionList["96"] = Thunderstorm;
-    conditionList["999"] = NotAvailable;
+    conditionList.insert(QStringLiteral("3"),  Overcast);
+    conditionList.insert(QStringLiteral("30"), Overcast);
+    conditionList.insert(QStringLiteral("4"),  Haze);
+    conditionList.insert(QStringLiteral("40"), Haze);
+    conditionList.insert(QStringLiteral("45"), Haze);
+    conditionList.insert(QStringLiteral("48"), Haze);
+    conditionList.insert(QStringLiteral("49"), Haze);
+    conditionList.insert(QStringLiteral("5"),  Mist);
+    conditionList.insert(QStringLiteral("50"), Mist);
+    conditionList.insert(QStringLiteral("51"), Mist);
+    conditionList.insert(QStringLiteral("53"), Mist);
+    conditionList.insert(QStringLiteral("55"), Mist);
+    conditionList.insert(QStringLiteral("56"), FreezingDrizzle);
+    conditionList.insert(QStringLiteral("57"), FreezingDrizzle);
+    conditionList.insert(QStringLiteral("6"),  Rain);
+    conditionList.insert(QStringLiteral("60"), LightRain);
+    conditionList.insert(QStringLiteral("61"), LightRain);
+    conditionList.insert(QStringLiteral("63"), Rain);
+    conditionList.insert(QStringLiteral("65"), Rain);
+    conditionList.insert(QStringLiteral("66"), FreezingRain);
+    conditionList.insert(QStringLiteral("67"), FreezingRain);
+    conditionList.insert(QStringLiteral("68"), RainSnow);
+    conditionList.insert(QStringLiteral("69"), RainSnow);
+    conditionList.insert(QStringLiteral("7"),  Snow);
+    conditionList.insert(QStringLiteral("70"), LightSnow);
+    conditionList.insert(QStringLiteral("71"), LightSnow);
+    conditionList.insert(QStringLiteral("73"), Snow);
+    conditionList.insert(QStringLiteral("75"), Flurries);
+    conditionList.insert(QStringLiteral("8"),  Showers);
+    conditionList.insert(QStringLiteral("81"), Showers);
+    conditionList.insert(QStringLiteral("82"), Showers);
+    conditionList.insert(QStringLiteral("83"), RainSnow);
+    conditionList.insert(QStringLiteral("84"), RainSnow);
+    conditionList.insert(QStringLiteral("85"), Snow);
+    conditionList.insert(QStringLiteral("86"), Snow);
+    conditionList.insert(QStringLiteral("9"),  Thunderstorm);
+    conditionList.insert(QStringLiteral("90"), Thunderstorm);
+    conditionList.insert(QStringLiteral("96"), Thunderstorm);
+    conditionList.insert(QStringLiteral("999"), NotAvailable);
 
     return conditionList;
 }
 
-QMap<QString, IonInterface::ConditionIcons> WetterComIon::setupDayIconMappings(void) const
+QMap<QString, IonInterface::ConditionIcons> WetterComIon::setupDayIconMappings() const
 {
     QMap<QString, ConditionIcons> conditionList = setupCommonIconMappings();
 
-    conditionList["0"]  = ClearDay;
-    conditionList["1"]  = FewCloudsDay;
-    conditionList["10"] = FewCloudsDay;
-    conditionList["2"]  = PartlyCloudyDay;
-    conditionList["20"] = PartlyCloudyDay;
-    conditionList["80"] = ChanceShowersDay;
-    conditionList["95"] = ChanceThunderstormDay;
+    conditionList.insert(QStringLiteral("0"),  ClearDay);
+    conditionList.insert(QStringLiteral("1"),  FewCloudsDay);
+    conditionList.insert(QStringLiteral("10"), FewCloudsDay);
+    conditionList.insert(QStringLiteral("2"),  PartlyCloudyDay);
+    conditionList.insert(QStringLiteral("20"), PartlyCloudyDay);
+    conditionList.insert(QStringLiteral("80"), ChanceShowersDay);
+    conditionList.insert(QStringLiteral("95"), ChanceThunderstormDay);
 
     return conditionList;
 }
 
-QMap<QString, IonInterface::ConditionIcons> const& WetterComIon::dayIcons(void) const
+QMap<QString, IonInterface::ConditionIcons> const& WetterComIon::dayIcons() const
 {
     static QMap<QString, ConditionIcons> const val = setupDayIconMappings();
     return val;
 }
 
-QMap<QString, IonInterface::ConditionIcons> WetterComIon::setupNightIconMappings(void) const
+QMap<QString, IonInterface::ConditionIcons> WetterComIon::setupNightIconMappings() const
 {
     QMap<QString, ConditionIcons> conditionList = setupCommonIconMappings();
 
-    conditionList["0"]  = ClearNight;
-    conditionList["1"]  = FewCloudsNight;
-    conditionList["10"] = FewCloudsNight;
-    conditionList["2"]  = PartlyCloudyNight;
-    conditionList["20"] = PartlyCloudyNight;
-    conditionList["80"] = ChanceShowersNight;
-    conditionList["95"] = ChanceThunderstormNight;
+    conditionList.insert(QStringLiteral("0"),  ClearNight);
+    conditionList.insert(QStringLiteral("1"),  FewCloudsNight);
+    conditionList.insert(QStringLiteral("10"), FewCloudsNight);
+    conditionList.insert(QStringLiteral("2"),  PartlyCloudyNight);
+    conditionList.insert(QStringLiteral("20"), PartlyCloudyNight);
+    conditionList.insert(QStringLiteral("80"), ChanceShowersNight);
+    conditionList.insert(QStringLiteral("95"), ChanceThunderstormNight);
 
     return conditionList;
 }
 
-QMap<QString, IonInterface::ConditionIcons> const& WetterComIon::nightIcons(void) const
+QMap<QString, IonInterface::ConditionIcons> const& WetterComIon::nightIcons() const
 {
     static QMap<QString, ConditionIcons> const val = setupNightIconMappings();
     return val;
 }
 
-QMap<QString, QString> WetterComIon::setupCommonConditionMappings(void) const
+QMap<QString, QString> WetterComIon::setupCommonConditionMappings() const
 {
     QMap<QString, QString> conditionList;
-    conditionList["1"]  = i18nc("weather condition", "few clouds");
-    conditionList["10"] = i18nc("weather condition", "few clouds");
-    conditionList["2"]  = i18nc("weather condition", "cloudy");
-    conditionList["20"] = i18nc("weather condition", "cloudy");
-    conditionList["3"]  = i18nc("weather condition", "overcast");
-    conditionList["30"] = i18nc("weather condition", "overcast");
-    conditionList["4"]  = i18nc("weather condition", "haze");
-    conditionList["40"] = i18nc("weather condition", "haze");
-    conditionList["45"] = i18nc("weather condition", "haze");
-    conditionList["48"] = i18nc("weather condition", "fog with icing");
-    conditionList["49"] = i18nc("weather condition", "fog with icing");
-    conditionList["5"]  = i18nc("weather condition", "drizzle");
-    conditionList["50"] = i18nc("weather condition", "drizzle");
-    conditionList["51"] = i18nc("weather condition", "light drizzle");
-    conditionList["53"] = i18nc("weather condition", "drizzle");
-    conditionList["55"] = i18nc("weather condition", "heavy drizzle");
-    conditionList["56"] = i18nc("weather condition", "freezing drizzle");
-    conditionList["57"] = i18nc("weather condition", "heavy freezing drizzle");
-    conditionList["6"]  = i18nc("weather condition", "rain");
-    conditionList["60"] = i18nc("weather condition", "light rain");
-    conditionList["61"] = i18nc("weather condition", "light rain");
-    conditionList["63"] = i18nc("weather condition", "moderate rain");
-    conditionList["65"] = i18nc("weather condition", "heavy rain");
-    conditionList["66"] = i18nc("weather condition", "light freezing rain");
-    conditionList["67"] = i18nc("weather condition", "freezing rain");
-    conditionList["68"] = i18nc("weather condition", "light rain snow");
-    conditionList["69"] = i18nc("weather condition", "heavy rain snow");
-    conditionList["7"]  = i18nc("weather condition", "snow");
-    conditionList["70"] = i18nc("weather condition", "light snow");
-    conditionList["71"] = i18nc("weather condition", "light snow");
-    conditionList["73"] = i18nc("weather condition", "moderate snow");
-    conditionList["75"] = i18nc("weather condition", "heavy snow");
-    conditionList["8"]  = i18nc("weather condition", "showers");
-    conditionList["80"] = i18nc("weather condition", "light showers");
-    conditionList["81"] = i18nc("weather condition", "showers");
-    conditionList["82"] = i18nc("weather condition", "heavy showers");
-    conditionList["83"] = i18nc("weather condition", "light snow rain showers");
-    conditionList["84"] = i18nc("weather condition", "heavy snow rain showers");
-    conditionList["85"] = i18nc("weather condition", "light snow showers");
-    conditionList["86"] = i18nc("weather condition", "snow showers");
-    conditionList["9"]  = i18nc("weather condition", "thunderstorm");
-    conditionList["90"] = i18nc("weather condition", "thunderstorm");
-    conditionList["95"] = i18nc("weather condition", "light thunderstorm");
-    conditionList["96"] = i18nc("weather condition", "heavy thunderstorm");
-    conditionList["999"] = i18nc("weather condition", "n/a");
+    conditionList.insert(QStringLiteral("1"),  i18nc("weather condition", "few clouds"));
+    conditionList.insert(QStringLiteral("10"), i18nc("weather condition", "few clouds"));
+    conditionList.insert(QStringLiteral("2"),  i18nc("weather condition", "cloudy"));
+    conditionList.insert(QStringLiteral("20"), i18nc("weather condition", "cloudy"));
+    conditionList.insert(QStringLiteral("3"),  i18nc("weather condition", "overcast"));
+    conditionList.insert(QStringLiteral("30"), i18nc("weather condition", "overcast"));
+    conditionList.insert(QStringLiteral("4"),  i18nc("weather condition", "haze"));
+    conditionList.insert(QStringLiteral("40"), i18nc("weather condition", "haze"));
+    conditionList.insert(QStringLiteral("45"), i18nc("weather condition", "haze"));
+    conditionList.insert(QStringLiteral("48"), i18nc("weather condition", "fog with icing"));
+    conditionList.insert(QStringLiteral("49"), i18nc("weather condition", "fog with icing"));
+    conditionList.insert(QStringLiteral("5"),  i18nc("weather condition", "drizzle"));
+    conditionList.insert(QStringLiteral("50"), i18nc("weather condition", "drizzle"));
+    conditionList.insert(QStringLiteral("51"), i18nc("weather condition", "light drizzle"));
+    conditionList.insert(QStringLiteral("53"), i18nc("weather condition", "drizzle"));
+    conditionList.insert(QStringLiteral("55"), i18nc("weather condition", "heavy drizzle"));
+    conditionList.insert(QStringLiteral("56"), i18nc("weather condition", "freezing drizzle"));
+    conditionList.insert(QStringLiteral("57"), i18nc("weather condition", "heavy freezing drizzle"));
+    conditionList.insert(QStringLiteral("6"),  i18nc("weather condition", "rain"));
+    conditionList.insert(QStringLiteral("60"), i18nc("weather condition", "light rain"));
+    conditionList.insert(QStringLiteral("61"), i18nc("weather condition", "light rain"));
+    conditionList.insert(QStringLiteral("63"), i18nc("weather condition", "moderate rain"));
+    conditionList.insert(QStringLiteral("65"), i18nc("weather condition", "heavy rain"));
+    conditionList.insert(QStringLiteral("66"), i18nc("weather condition", "light freezing rain"));
+    conditionList.insert(QStringLiteral("67"), i18nc("weather condition", "freezing rain"));
+    conditionList.insert(QStringLiteral("68"), i18nc("weather condition", "light rain snow"));
+    conditionList.insert(QStringLiteral("69"), i18nc("weather condition", "heavy rain snow"));
+    conditionList.insert(QStringLiteral("7"),  i18nc("weather condition", "snow"));
+    conditionList.insert(QStringLiteral("70"), i18nc("weather condition", "light snow"));
+    conditionList.insert(QStringLiteral("71"), i18nc("weather condition", "light snow"));
+    conditionList.insert(QStringLiteral("73"), i18nc("weather condition", "moderate snow"));
+    conditionList.insert(QStringLiteral("75"), i18nc("weather condition", "heavy snow"));
+    conditionList.insert(QStringLiteral("8"),  i18nc("weather condition", "showers"));
+    conditionList.insert(QStringLiteral("80"), i18nc("weather condition", "light showers"));
+    conditionList.insert(QStringLiteral("81"), i18nc("weather condition", "showers"));
+    conditionList.insert(QStringLiteral("82"), i18nc("weather condition", "heavy showers"));
+    conditionList.insert(QStringLiteral("83"), i18nc("weather condition", "light snow rain showers"));
+    conditionList.insert(QStringLiteral("84"), i18nc("weather condition", "heavy snow rain showers"));
+    conditionList.insert(QStringLiteral("85"), i18nc("weather condition", "light snow showers"));
+    conditionList.insert(QStringLiteral("86"), i18nc("weather condition", "snow showers"));
+    conditionList.insert(QStringLiteral("9"),  i18nc("weather condition", "thunderstorm"));
+    conditionList.insert(QStringLiteral("90"), i18nc("weather condition", "thunderstorm"));
+    conditionList.insert(QStringLiteral("95"), i18nc("weather condition", "light thunderstorm"));
+    conditionList.insert(QStringLiteral("96"), i18nc("weather condition", "heavy thunderstorm"));
+    conditionList.insert(QStringLiteral("999"), i18nc("weather condition", "n/a"));
 
     return conditionList;
 }
 
-QMap<QString, QString> WetterComIon::setupDayConditionMappings(void) const
+QMap<QString, QString> WetterComIon::setupDayConditionMappings() const
 {
     QMap<QString, QString> conditionList = setupCommonConditionMappings();
-    conditionList["0"]  = i18nc("weather condition", "sunny");
+    conditionList.insert(QStringLiteral("0"), i18nc("weather condition", "sunny"));
     return conditionList;
 }
 
-QMap<QString, QString> const& WetterComIon::dayConditions(void) const
+QMap<QString, QString> const& WetterComIon::dayConditions() const
 {
     static QMap<QString, QString> const val = setupDayConditionMappings();
     return val;
 }
 
-QMap<QString, QString> WetterComIon::setupNightConditionMappings(void) const
+QMap<QString, QString> WetterComIon::setupNightConditionMappings() const
 {
     QMap<QString, QString> conditionList = setupCommonConditionMappings();
-    conditionList["0"]  = i18nc("weather condition", "clear sky");
+    conditionList.insert(QStringLiteral("0"), i18nc("weather condition", "clear sky"));
     return conditionList;
 }
 
-QMap<QString, QString> const& WetterComIon::nightConditions(void) const
+QMap<QString, QString> const& WetterComIon::nightConditions() const
 {
     static QMap<QString, QString> const val = setupNightConditionMappings();
     return val;
@@ -257,30 +253,31 @@ bool WetterComIon::updateIonSource(const QString& source)
     // ionname|validate|place_name|extra - Triggers validation of place
     // ionname|weather|place_name|extra - Triggers receiving weather of place
 
-    QStringList sourceAction = source.split('|');
+    const QStringList sourceAction = source.split(QLatin1Char('|'));
 
     if (sourceAction.size() < 3) {
-        setData(source, "validate", "wettercom|malformed");
+        setData(source, QStringLiteral("validate"), QStringLiteral("wettercom|malformed"));
         return true;
     }
 
-    if (sourceAction[1] == "validate" && sourceAction.size() >= 3) {
+    if (sourceAction[1] == QLatin1String("validate") && sourceAction.size() >= 3) {
         // Look for places to match
         findPlace(sourceAction[2], source);
         return true;
-    } else if (sourceAction[1] == "weather" && sourceAction.size() >= 3) {
-        qWarning()<<"WWWW"<<sourceAction;
+    }
+
+    if (sourceAction[1] == QLatin1String("weather") && sourceAction.size() >= 3) {
         if (sourceAction.count() >= 4) {
             if (sourceAction[2].isEmpty()) {
-                setData(source, "validate", "wettercom|malformed");
+                setData(source, QStringLiteral("validate"), QStringLiteral("wettercom|malformed"));
                 return true;
             }
 
             // Extra data format: placeCode;displayName
-            QStringList extraData = sourceAction[3].split(';');
+            const QStringList extraData = sourceAction[3].split(QLatin1Char(';'));
 
             if (extraData.count() != 2) {
-                setData(source, "validate", "wettercom|malformed");
+                setData(source, QStringLiteral("validate"), QStringLiteral("wettercom|malformed"));
                 return true;
             }
 
@@ -293,15 +290,13 @@ bool WetterComIon::updateIonSource(const QString& source)
             fetchForecast(sourceAction[2]);
 
             return true;
-        } else {
-            return false;
         }
-    } else {
-        setData(source, "validate", "wettercom|malformed");
-        return true;
+
+        return false;
     }
 
-    return false;
+    setData(source, QStringLiteral("validate"), QStringLiteral("wettercom|malformed"));
+    return true;
 }
 
 
@@ -315,20 +310,19 @@ void WetterComIon::findPlace(const QString& place, const QString& source)
     md5.addData(QString::fromLatin1(PROJECTNAME).toUtf8());
     md5.addData(QString::fromLatin1(APIKEY).toUtf8());
     md5.addData(place.toUtf8());
+    const QString encodedKey = QString::fromLatin1(md5.result().toHex());
 
-    QUrl url = QString::fromLatin1(SEARCH_URL).arg(place).arg(md5.result().toHex().data());
+    const QUrl url = QString::fromLatin1(SEARCH_URL).arg(place, encodedKey);
 
-    m_job = KIO::get(url.url(), KIO::Reload, KIO::HideProgressInfo);
-    m_job->addMetaData("cookies", "none");    // Disable displaying cookies
-    m_searchJobXml.insert(m_job, new QXmlStreamReader);
-    m_searchJobList.insert(m_job, source);
+    KIO::TransferJob* getJob = KIO::get(url, KIO::Reload, KIO::HideProgressInfo);
+    getJob->addMetaData(QStringLiteral("cookies"), QStringLiteral("none")); // Disable displaying cookies
+    m_searchJobXml.insert(getJob, new QXmlStreamReader);
+    m_searchJobList.insert(getJob, source);
 
-    if (m_job) {
-        connect(m_job, SIGNAL(data(KIO::Job*,QByteArray)), this,
-                SLOT(setup_slotDataArrived(KIO::Job*,QByteArray)));
-        connect(m_job, SIGNAL(result(KJob*)), this,
-                SLOT(setup_slotJobFinished(KJob*)));
-    }
+    connect(getJob, &KIO::TransferJob::data,
+            this, &WetterComIon::setup_slotDataArrived);
+    connect(getJob, &KJob::result,
+            this, &WetterComIon::setup_slotJobFinished);
 }
 
 void WetterComIon::setup_slotDataArrived(KIO::Job *job, const QByteArray &data)
@@ -345,8 +339,7 @@ void WetterComIon::setup_slotDataArrived(KIO::Job *job, const QByteArray &data)
 void WetterComIon::setup_slotJobFinished(KJob *job)
 {
     if (job->error() == 149) {
-        setData(m_searchJobList[job], "validate",
-                QString::fromLatin1("wettercom|timeout"));
+        setData(m_searchJobList[job], QStringLiteral("validate"), QStringLiteral("wettercom|timeout"));
         disconnectSource(m_searchJobList[job], this);
         m_searchJobList.remove(job);
         delete m_searchJobXml[job];
@@ -373,10 +366,12 @@ void WetterComIon::parseSearchResults(const QString& source, QXmlStreamReader& x
     while (!xml.atEnd()) {
         xml.readNext();
 
+        const QStringRef elementName = xml.name();
+
         if (xml.isEndElement()) {
-            if (xml.name() == "search") {
+            if (elementName == QLatin1String("search")) {
                 break;
-            } else if (xml.name() == "item") {
+            } else if (elementName == QLatin1String("item")) {
                 // we parsed a place from the search result
                 QString placeName;
 
@@ -395,24 +390,24 @@ void WetterComIon::parseSearchResults(const QString& source, QXmlStreamReader& x
                 m_place[placeName].placeCode = code;
                 m_locations.append(placeName);
 
-                name = "";
-                code = "";
-                quarter = "";
-                country = "";
-                state = "";
+                name.clear();
+                code.clear();
+                quarter.clear();
+                country.clear();
+                state.clear();
             }
         }
 
         if (xml.isStartElement()) {
-            if (xml.name() == "name") {
+            if (elementName == QLatin1String("name")) {
                 name = xml.readElementText();
-            } else if (xml.name() == "city_code") {
+            } else if (elementName == QLatin1String("city_code")) {
                 code = xml.readElementText();
-            } else if (xml.name() == "quarter") {
+            } else if (elementName == QLatin1String("quarter")) {
                 quarter = xml.readElementText();
-            } else if (xml.name() == "adm_1_code") {
+            } else if (elementName == QLatin1String("adm_1_code")) {
                 country = xml.readElementText();
-            } else if (xml.name() == "adm_2_name") {
+            } else if (elementName == QLatin1String("adm_2_name")) {
                 state = xml.readElementText();
             }
         }
@@ -423,48 +418,35 @@ void WetterComIon::parseSearchResults(const QString& source, QXmlStreamReader& x
 
 void WetterComIon::validate(const QString& source, bool parseError)
 {
-    bool beginflag = true;
-
     if (!m_locations.count() || parseError) {
-        QStringList invalidPlace = source.split('|');
+        const QString invalidPlace = source.section(QLatin1Char('|'), 2, 2);
 
-        if (m_place[invalidPlace[2]].name.isEmpty()) {
-            setData(source, "validate",
-                    QString::fromLatin1("wettercom|invalid|multiple|%1")
-                    .arg(invalidPlace[2]));
+        if (m_place[invalidPlace].name.isEmpty()) {
+            setData(source, QStringLiteral("validate"),
+                    QVariant(QStringLiteral("wettercom|invalid|multiple|") + invalidPlace));
         }
 
         m_locations.clear();
 
         return;
+    }
+
+    QString placeList;
+    foreach(const QString &place, m_locations) {
+        // Extra data format: placeCode;displayName
+        placeList.append(QStringLiteral("|place|") + place + QStringLiteral("|extra|") +
+                         m_place[place].placeCode + QLatin1Char(';') + m_place[place].displayName);
+    }
+
+    qDebug() << "Returning place list:" << placeList;
+
+    if (m_locations.count() > 1) {
+        setData(source, QStringLiteral("validate"),
+                QVariant(QStringLiteral("wettercom|valid|multiple") + placeList));
     } else {
-        QString placeList;
-        foreach(const QString &place, m_locations) {
-            // Extra data format: placeCode;displayName
-            if (beginflag) {
-                placeList.append(QString::fromLatin1("%1|extra|%2;%3")
-                                 .arg(place).arg(m_place[place].placeCode)
-                                 .arg(m_place[place].displayName));
-                beginflag = false;
-            } else {
-                placeList.append(QString::fromLatin1("|place|%1|extra|%2;%3")
-                                 .arg(place).arg(m_place[place].placeCode)
-                                 .arg(m_place[place].displayName));
-            }
-        }
-
-        qDebug() << "Returning place list:" << placeList;
-
-        if (m_locations.count() > 1) {
-            setData(source, "validate",
-                    QString::fromLatin1("wettercom|valid|multiple|place|%1")
-                    .arg(placeList));
-        } else {
-            placeList[0] = placeList[0].toUpper();
-            setData(source, "validate",
-                    QString::fromLatin1("wettercom|valid|single|place|%1")
-                    .arg(placeList));
-        }
+        placeList[7] = placeList[7].toUpper();
+        setData(source, QStringLiteral("validate"),
+                QVariant(QStringLiteral("wettercom|valid|single") + placeList));
     }
 
     m_locations.clear();
@@ -488,21 +470,19 @@ void WetterComIon::fetchForecast(const QString& source)
     md5.addData(QString::fromLatin1(PROJECTNAME).toUtf8());
     md5.addData(QString::fromLatin1(APIKEY).toUtf8());
     md5.addData(m_place[source].placeCode.toUtf8());
+    const QString encodedKey = QString::fromLatin1(md5.result().toHex());
 
-    QUrl url = QString::fromLatin1(FORECAST_URL)
-               .arg(m_place[source].placeCode).arg(md5.result().toHex().data());
+    const QUrl url = QString::fromLatin1(FORECAST_URL).arg(m_place[source].placeCode, encodedKey);
 
-    m_job = KIO::get(url.url(), KIO::Reload, KIO::HideProgressInfo);
-    m_job->addMetaData("cookies", "none");
-    m_forecastJobXml.insert(m_job, new QXmlStreamReader);
-    m_forecastJobList.insert(m_job, source);
+    KIO::TransferJob* getJob = KIO::get(url, KIO::Reload, KIO::HideProgressInfo);
+    getJob->addMetaData(QStringLiteral("cookies"), QStringLiteral("none"));
+    m_forecastJobXml.insert(getJob, new QXmlStreamReader);
+    m_forecastJobList.insert(getJob, source);
 
-    if (m_job) {
-        connect(m_job, SIGNAL(data(KIO::Job*,QByteArray)), this,
-                SLOT(forecast_slotDataArrived(KIO::Job*,QByteArray)));
-        connect(m_job, SIGNAL(result(KJob*)), this,
-                SLOT(forecast_slotJobFinished(KJob*)));
-    }
+    connect(getJob, &KIO::TransferJob::data,
+            this, &WetterComIon::forecast_slotDataArrived);
+    connect(getJob, &KJob::result,
+            this, &WetterComIon::forecast_slotJobFinished);
 }
 
 void WetterComIon::forecast_slotDataArrived(KIO::Job *job, const QByteArray &data)
@@ -566,10 +546,13 @@ void WetterComIon::parseWeatherForecast(const QString& source, QXmlStreamReader&
 
         qDebug() << "parsing xml elem: " << xml.name();
 
+        const QStringRef elementName = xml.name();
+
         if (xml.isEndElement()) {
-            if (xml.name() == "city") {
+            if (elementName == QLatin1String("city")) {
                 break;
-            } else if (xml.name() == "date") {
+            }
+            if (elementName == QLatin1String("date")) {
                 // we have parsed a complete day
 
                 forecastPeriod->period = QDateTime::fromTime_t(summaryUtcTime);
@@ -583,11 +566,11 @@ void WetterComIon::parseWeatherForecast(const QString& source, QXmlStreamReader&
                 m_weatherData[source].forecasts.append(forecastPeriod);
                 forecastPeriod = new WeatherData::ForecastPeriod;
 
-                date = "";
+                date.clear();
                 summaryWeather = -1;
                 summaryProbability = 0;
                 summaryUtcTime = 0;
-            } else if (xml.name() == "time") {
+            } else if (elementName == QLatin1String("time")) {
                 // we have parsed one forecast
 
                 qDebug() << "Parsed a forecast interval:" << date << time;
@@ -629,22 +612,22 @@ void WetterComIon::parseWeatherForecast(const QString& source, QXmlStreamReader&
                 weather = -1;
                 probability = 0;
                 utcTime = localTime = 0;
-                time = "";
+                time.clear();
             }
         }
 
         if (xml.isStartElement()) {
-            if (xml.name() == "date") {
-                date = xml.attributes().value("value").toString();
-            } else if (xml.name() == "time") {
-                time = xml.attributes().value("value").toString();
-            } else if (xml.name() == "tx") {
+            if (elementName == QLatin1String("date")) {
+                date = xml.attributes().value(QStringLiteral("value")).toString();
+            } else if (elementName == QLatin1String("time")) {
+                time = xml.attributes().value(QStringLiteral("value")).toString();
+            } else if (elementName == QLatin1String("tx")) {
                 tempMax = qRound(xml.readElementText().toDouble());
                 qDebug() << "parsed t_max:" << tempMax;
-            } else if (xml.name() == "tn") {
+            } else if (elementName == QLatin1String("tn")) {
                 tempMin = qRound(xml.readElementText().toDouble());
                 qDebug() << "parsed t_min:" << tempMin;
-            } else if (xml.name() == "w") {
+            } else if (elementName == QLatin1String("w")) {
                 int tmp = xml.readElementText().toInt();
 
                 if (!time.isEmpty())
@@ -653,10 +636,10 @@ void WetterComIon::parseWeatherForecast(const QString& source, QXmlStreamReader&
                     summaryWeather = tmp;
 
                 qDebug() << "parsed weather condition:" << tmp;
-            } else if (xml.name() == "name") {
+            } else if (elementName == QLatin1String("name")) {
                 m_weatherData[source].stationName = xml.readElementText();
                 qDebug() << "parsed station name:" << m_weatherData[source].stationName;
-            } else if (xml.name() == "pc") {
+            } else if (elementName == QLatin1String("pc")) {
                 int tmp = xml.readElementText().toInt();
 
                 if (!time.isEmpty())
@@ -665,16 +648,16 @@ void WetterComIon::parseWeatherForecast(const QString& source, QXmlStreamReader&
                     summaryProbability = tmp;
 
                 qDebug() << "parsed probability:" << probability;
-            } else if (xml.name() == "text") {
+            } else if (elementName == QLatin1String("text")) {
                 m_weatherData[source].credits = xml.readElementText();
                 qDebug() << "parsed credits:" << m_weatherData[source].credits;
-            } else if (xml.name() == "link") {
+            } else if (elementName == QLatin1String("link")) {
                 m_weatherData[source].creditsUrl = xml.readElementText();
                 qDebug() << "parsed credits url:" << m_weatherData[source].creditsUrl;
-            } else if (xml.name() == "d") {
+            } else if (elementName == QLatin1String("d")) {
                 localTime = xml.readElementText().toInt();
                 qDebug() << "parsed local time:" << localTime;
-            } else if (xml.name() == "du") {
+            } else if (elementName == QLatin1String("du")) {
                 int tmp = xml.readElementText().toInt();
 
                 if (!time.isEmpty())
@@ -702,13 +685,13 @@ void WetterComIon::updateWeather(const QString& source, bool parseError)
                             .arg(m_place[source].displayName);
 
     Plasma::DataEngine::Data data;
-    data.insert("Place", m_place[source].displayName);
+    data.insert(QStringLiteral("Place"), m_place[source].displayName);
 
     if (!parseError && !m_weatherData[source].forecasts.isEmpty()) {
-        data.insert("Station", m_place[source].displayName);
+        data.insert(QStringLiteral("Station"), m_place[source].displayName);
         //data.insert("Condition Icon", "N/A");
         //data.insert("Temperature", "N/A");
-        data.insert("Temperature Unit", QString::number(KUnitConversion::Celsius));
+        data.insert(QStringLiteral("Temperature Unit"), KUnitConversion::Celsius);
 
         int i = 0;
         foreach(WeatherData::ForecastPeriod * forecastPeriod, m_weatherData[source].forecasts) {
@@ -747,10 +730,10 @@ void WetterComIon::updateWeather(const QString& source, bool parseError)
         }
 
         // Set number of forecasts per day/night supported
-        data.insert("Total Weather Days", i);
+        data.insert(QStringLiteral("Total Weather Days"), i);
 
-        data.insert("Credit", m_weatherData[source].credits); // FIXME i18n?
-        data.insert("Credit Url", m_weatherData[source].creditsUrl);
+        data.insert(QStringLiteral("Credit"), m_weatherData[source].credits); // FIXME i18n?
+        data.insert(QStringLiteral("Credit Url"), m_weatherData[source].creditsUrl);
 
         qDebug() << "updated weather data:" << weatherSource << data;
     } else {
