@@ -264,8 +264,8 @@ void TasksModel::Private::initModels()
         }
     );
 
-    // If we're in manual sort mode, we need to update the sort map on row removals.
-    QObject::connect(concatProxyModel, &QAbstractItemModel::rowsAboutToBeRemoved, q,
+    // If we're in manual sort mode, we need to update the sort map after row removals.
+    QObject::connect(concatProxyModel, &QAbstractItemModel::rowsRemoved, q,
         [this](const QModelIndex &parent, int first, int last) {
             Q_UNUSED(parent)
 
@@ -685,27 +685,29 @@ bool TasksModel::Private::lessThan(const QModelIndex &left, const QModelIndex &r
             return (left.row() < right.row());
         } else if (left.data(AbstractTasksModel::IsLauncher).toBool() && !right.data(AbstractTasksModel::IsLauncher).toBool()) {
             if (launchInPlace) {
-                const int rightPos = q->launcherPosition(right.data(AbstractTasksModel::LauncherUrl).toUrl());
+                const int leftPos = q->launcherPosition(left.data(AbstractTasksModel::LauncherUrlWithoutIcon).toUrl());
+                const int rightPos = q->launcherPosition(right.data(AbstractTasksModel::LauncherUrlWithoutIcon).toUrl());
 
                 if (rightPos != -1) {
-                    return (left.row() < rightPos);
+                    return (leftPos < rightPos);
                 }
             }
 
             return true;
         } else if (!left.data(AbstractTasksModel::IsLauncher).toBool() && right.data(AbstractTasksModel::IsLauncher).toBool()) {
             if (launchInPlace) {
-                const int leftPos = q->launcherPosition(left.data(AbstractTasksModel::LauncherUrl).toUrl());
+                const int leftPos = q->launcherPosition(left.data(AbstractTasksModel::LauncherUrlWithoutIcon).toUrl());
+                const int rightPos = q->launcherPosition(right.data(AbstractTasksModel::LauncherUrlWithoutIcon).toUrl());
 
                 if (leftPos != -1) {
-                    return (leftPos < right.row());
+                    return (leftPos < rightPos);
                 }
             }
 
             return false;
         } else if (launchInPlace) {
-            const int leftPos = q->launcherPosition(left.data(AbstractTasksModel::LauncherUrl).toUrl());
-            const int rightPos = q->launcherPosition(right.data(AbstractTasksModel::LauncherUrl).toUrl());
+            const int leftPos = q->launcherPosition(left.data(AbstractTasksModel::LauncherUrlWithoutIcon).toUrl());
+            const int rightPos = q->launcherPosition(right.data(AbstractTasksModel::LauncherUrlWithoutIcon).toUrl());
 
             if (leftPos != -1 && rightPos != -1) {
                 return (leftPos < rightPos);
@@ -1123,9 +1125,9 @@ bool TasksModel::requestAddLauncher(const QUrl &url)
     if (d->launcherTasksModel) {
         bool added = d->launcherTasksModel->requestAddLauncher(url);
 
-        // If using manual sorting and launch-in-place sorting, we need
-        // to trigger a sort map update to move any window tasks to their
-        // launcher position now.
+        // If using manual and launch-in-place sorting with separate launchers,
+        // we need to trigger a sort map update to move any window tasks to
+        // their launcher position now.
         if (added && d->sortMode == SortManual && (d->launchInPlace || !d->separateLaunchers)) {
             d->updateManualSortMap();
             d->forceResort();
@@ -1140,7 +1142,17 @@ bool TasksModel::requestAddLauncher(const QUrl &url)
 bool TasksModel::requestRemoveLauncher(const QUrl &url)
 {
     if (d->launcherTasksModel) {
-        return d->launcherTasksModel->requestRemoveLauncher(url);
+        bool removed = d->launcherTasksModel->requestRemoveLauncher(url);
+
+        // If using manual and launch-in-place sorting with separate launchers,
+        // we need to trigger a sort map update to move any window tasks no
+        // longer backed by a launcher out of the launcher area.
+        if (removed && d->sortMode == SortManual && (d->launchInPlace || !d->separateLaunchers)) {
+            d->updateManualSortMap();
+            d->forceResort();
+        }
+
+        return removed;
     }
 
     return false;
@@ -1529,7 +1541,7 @@ bool TasksModel::filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent
             }
 
             if ((!appId.isEmpty() && appId == filterIndex.data(AbstractTasksModel::AppId).toString())
-                || (appName.isEmpty() && appName == filterIndex.data(AbstractTasksModel::AppName).toString())) {
+                || (!appName.isEmpty() && appName == filterIndex.data(AbstractTasksModel::AppName).toString())) {
                 return false;
             }
         }
