@@ -42,9 +42,15 @@ public Q_SLOTS:
     void brightnessChanged(int percent);
     void keyboardBrightnessChanged(int percent);
     void volumeChanged(int percent);
+    void microphoneVolumeChanged(int percent);
     void mediaPlayerVolumeChanged(int percent, const QString &playerName, const QString &playerIconName);
     void kbdLayoutChanged(const QString &layoutName);
     void virtualDesktopChanged(const QString &currentVirtualDesktopName);
+    void touchpadEnabledChanged(bool touchpadEnabled);
+    void wifiEnabledChanged(bool wifiEnabled);
+    void bluetoothEnabledChanged(bool bluetoothEnabled);
+    void wwanEnabledChanged(bool wwanEnabled);
+    void virtualKeyboardEnabledChanged(bool virtualKeyboardEnabled);
 
 Q_SIGNALS:
     void osdProgress(const QString &icon, const int percent, const QString &additionalText);
@@ -54,13 +60,16 @@ private Q_SLOTS:
     void hideOsd();
 
 private:
+    bool init();
+
     void showProgress(const QString &icon, const int percent, const QString &additionalText = QString());
     void showText(const QString &icon, const QString &text);
     void showOsd();
 
-    KDeclarative::QmlObject *m_osdObject;
-    QTimer *m_osdTimer;
-    int m_timeout;
+    QString m_osdPath;
+    KDeclarative::QmlObject *m_osdObject = nullptr;
+    QTimer *m_osdTimer = nullptr;
+    int m_timeout = 0;
 };
 
 #endif // OSD_H
